==> jc-1.4.0.tar.gz: polyglot/visit/CodeCleaner.h <==
// public class polyglot.visit.CodeCleaner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bfacf547455281dd polyglot_visit_CodeCleaner
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_CodeCleaner_H_
#define _JC_polyglot_visit_CodeCleaner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Block$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_visit_AlphaRenamer$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_CodeCleaner$sub_refs	_jc_polyglot_visit_CodeCleaner$sub_refs;
typedef struct _jc_polyglot_visit_CodeCleaner$sub_nonrefs	_jc_polyglot_visit_CodeCleaner$sub_nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner$refs	_jc_polyglot_visit_CodeCleaner$refs;
typedef struct _jc_polyglot_visit_CodeCleaner$nonrefs	_jc_polyglot_visit_CodeCleaner$nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner$object	_jc_polyglot_visit_CodeCleaner$object;

typedef const struct _jc_polyglot_visit_CodeCleaner$vmethods	_jc_polyglot_visit_CodeCleaner$vmethods;
typedef const struct _jc_polyglot_visit_CodeCleaner$vtable	_jc_polyglot_visit_CodeCleaner$vtable;
typedef const struct _jc_polyglot_visit_CodeCleaner$vtype	_jc_polyglot_visit_CodeCleaner$vtype;

// Constructors
extern void _jc_polyglot_visit_CodeCleaner$method$_init$0e3bea23b0bd47bf(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$clean$ce2259b43cfe4135(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$flattenBlock$e849b1624d5b202d(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$labelRefs$a54229b87977a6d8(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$clean$ce2259b43cfe4135;
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$flattenBlock$e849b1624d5b202d;
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$labelRefs$a54229b87977a6d8;
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_CodeCleaner$vmethods {
	struct _jc_object	*(*clean$ce2259b43cfe4135)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);
	struct _jc_object	*(*flattenBlock$e849b1624d5b202d)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);
	struct _jc_object	*(*labelRefs$a54229b87977a6d8)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_CodeCleaner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_CodeCleaner$vmethods	polyglot_visit_CodeCleaner;
};

// Vtype
struct _jc_polyglot_visit_CodeCleaner$vtype {
	_jc_type			type;
	_jc_polyglot_visit_CodeCleaner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner$sub_refs {
	struct _jc_object	*nf;
	struct _jc_polyglot_visit_AlphaRenamer$object	*alphaRen;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner$refs {
    _jc_polyglot_visit_CodeCleaner$sub_refs	polyglot_visit_CodeCleaner;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_CodeCleaner$sub_nonrefs	polyglot_visit_CodeCleaner;
};

// Object instance structure
struct _jc_polyglot_visit_CodeCleaner$object {
	_jc_polyglot_visit_CodeCleaner$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_CodeCleaner$vtype	*vtype;
	_jc_polyglot_visit_CodeCleaner$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_CodeCleaner$vtype _jc_polyglot_visit_CodeCleaner$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_CodeCleaner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_CodeCleaner$class_object;

#endif	/* _JC_polyglot_visit_CodeCleaner_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/CodeCleaner.h <==
// public class polyglot.visit.CodeCleaner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bfacf547455281dd polyglot_visit_CodeCleaner
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_CodeCleaner_H_
#define _JC_polyglot_visit_CodeCleaner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Block$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_visit_AlphaRenamer$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_CodeCleaner$sub_refs	_jc_polyglot_visit_CodeCleaner$sub_refs;
typedef struct _jc_polyglot_visit_CodeCleaner$sub_nonrefs	_jc_polyglot_visit_CodeCleaner$sub_nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner$refs	_jc_polyglot_visit_CodeCleaner$refs;
typedef struct _jc_polyglot_visit_CodeCleaner$nonrefs	_jc_polyglot_visit_CodeCleaner$nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner$object	_jc_polyglot_visit_CodeCleaner$object;

typedef const struct _jc_polyglot_visit_CodeCleaner$vmethods	_jc_polyglot_visit_CodeCleaner$vmethods;
typedef const struct _jc_polyglot_visit_CodeCleaner$vtable	_jc_polyglot_visit_CodeCleaner$vtable;
typedef const struct _jc_polyglot_visit_CodeCleaner$vtype	_jc_polyglot_visit_CodeCleaner$vtype;

// Constructors
extern void _jc_polyglot_visit_CodeCleaner$method$_init$0e3bea23b0bd47bf(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$clean$ce2259b43cfe4135(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$flattenBlock$e849b1624d5b202d(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$labelRefs$a54229b87977a6d8(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$clean$ce2259b43cfe4135;
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$flattenBlock$e849b1624d5b202d;
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$labelRefs$a54229b87977a6d8;
extern _jc_method _jc_polyglot_visit_CodeCleaner$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_CodeCleaner$vmethods {
	struct _jc_object	*(*clean$ce2259b43cfe4135)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*flattenBlock$e849b1624d5b202d)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*labelRefs$a54229b87977a6d8)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_CodeCleaner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_CodeCleaner$vmethods	polyglot_visit_CodeCleaner;
};

// Vtype
struct _jc_polyglot_visit_CodeCleaner$vtype {
	_jc_type			type;
	_jc_polyglot_visit_CodeCleaner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner$sub_refs {
	struct _jc_object	*nf;
	struct _jc_polyglot_visit_AlphaRenamer$object	*alphaRen;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner$refs {
    _jc_polyglot_visit_CodeCleaner$sub_refs	polyglot_visit_CodeCleaner;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_CodeCleaner$sub_nonrefs	polyglot_visit_CodeCleaner;
};

// Object instance structure
struct _jc_polyglot_visit_CodeCleaner$object {
	_jc_polyglot_visit_CodeCleaner$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_CodeCleaner$vtype	*vtype;
	_jc_polyglot_visit_CodeCleaner$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_CodeCleaner$vtype _jc_polyglot_visit_CodeCleaner$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_CodeCleaner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_CodeCleaner$class_object;

#endif	/* _JC_polyglot_visit_CodeCleaner_H_ */
